%
% Demonstrate simple classification using a multi-layer perceptron
% Matteo Roffilli Biofisica delle reti neurali aa.2005/2006
% using NETLAB
%

% Generate the train data
data = [1 1 ; 2 2 ; 3 3 ; 4 4];
label= [0 0 1 1]';

% Generate the test data
testdata = [1.5 1.5 ; 2.4 2.4 ; 2.6 2.6 ; 3.5 3.5];
testlabel= [0 0 1 1]'; 

% Now set up the MLP architecture
nhidden  = 20;
nout     = 1;
ncycles  = 200;	% Number of training cycles. 

% Create MLP network by using a sigmoidal = 'logistic' activation function
net = mlp(2, nhidden, nout, 'logistic');

% Set up MLP training options
options = foptions;
%options = zeros(1,18);
options(1) = 1;         % Print out error values
options(14) = ncycles;  % Max cycles number

% Train using qradient descent.
[net] = netopt(net, options, data, label, 'graddesc');
%[net] = netopt(net, options, data, label, 'quasinew');

% Compute network classification (Test)
result = mlpfwd(net, testdata)

% Convert output to classes
class = (result >= 0.5);

% -----------------------------------------------------
% Generate pictures
% -----------------------------------------------------

%create discriminant plot
xrange = [0:0.05:5];
yrange = [0:0.05:5];
[x y]=meshgrid(xrange,yrange);
tmp = mlpfwd(net,[x(:) y(:)]);
grid = reshape(tmp(:,1),size(x));

%train
figure;
plot(data((label==0),1),data(label==0,2),'ro');
hold on
plot(data((label>0),1),data(label>0,2),'b*')
contour(xrange,yrange,grid,[0.5 0.5],'k-');
title('train');
axis([0 5 0 5]);

%test
figure;
plot(testdata((class==0),1),testdata((class==0),2),'ro')
hold on
plot(testdata((class>0),1),testdata((class>0),2),'b*')
contour(xrange,yrange,grid,[0.5 0.5],'k-');
title('test');
axis([0 5 0 5]);

%clear all;
%close all;